==> CGI-CMS-0.37.tar.gz: CGI-CMS-0.37/cgi-bin/config/translate.pl <==
$VAR1 = {
    'en' => {
        'files'                   => 'Files',
        'openfile'                => 'Files',
        'save'                    => 'Save',
        'rename'                  => 'rename',
        'email'                   => 'Email Adress',
        'optionale email adresse' => 'optionale email adresse',
        'wrongusername'           => 'Wrong Username',
        'password'                => 'Password',
        'admincenter'             => 'Admin Center',
        'logout'                  => 'Logout',
        'category'                => 'Category',
        'dein name'               => 'dein name',
        'newmenu'                 => 'Create new Menu',
        'name'                    => 'Name',
        'details'                 => 'Details',
        'dumpdatabase'            => 'dumpdatabase',
        'properties'              => 'Properties',
        'nachricht senden'        => 'nachricht senden',
        'trash'                   => 'Trash',
        'translate'               => 'Translate',
        'delete'                  => 'Delete',
        'chars'                   => 'Chars left:',
        'editvmenu'               => 'editvmenu',
        'links_pro_page'          => 'links_pro_page',
        'non_unique'              => 'Non_unique',
        'mailsendet' =>
            '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
        'deletefile'           => 'Files',
        'cardinality'          => 'Cardinality',
        'speichern'            => 'Speichern',
        'pass'                 => 'Password',
        'edithmenu'            => 'edithmenu',
        'edittableprops'       => 'editTableProps',
        'sort'                 => 'sort',
        'index_type'           => 'Index_type',
        'profile'              => 'Profile',
        'next'                 => 'next',
        'feeds'                => 'Rss Feeds',
        'importoperabookmarks' => 'ImportOperaBookmarks',
        'upentry'              => 'Sort',
        'newentry'             => 'New Entry',
        'editaction'           => 'editaction',
        'nachricht'            => 'nachricht',
        'chmodfile'            => 'Files',
        'makedir'              => 'Files',
        'lostpass'             => 'Lost passwort',
        'savefile'             => 'Save',
        'export'               => 'Export',
        'haveacount'           => 'You already have an Acount',
        'savetreeviewentry'    => 'Save',
        'links'                => 'Bookmarks',
        'addtreeviewentry'     => 'Add new entry',
        'admin'                => 'Admin',
        'newdir'               => 'Files',
        'editentry'            => 'Edit Entry',
        'getpass'              => 'Lost Password',
        'null'                 => 'Null',
        'retry'                => 'retry',
        'exportoperabookmarks' => 'exportoperabookmarks',
        'preview'              => 'Preview',
        'bookmarks'            => 'Bookmarks',
        'repairtable'          => 'Repair Table',
        'newpass'              => 'New Password',
        'city'                 => 'City',
        'column_name'          => 'Column_name',
        'showtables'           => 'Show Tables',
        'analyzetable'         => 'Analyze Table',
        'familyname'           => 'Family Name',
        'auswahl aufheben'     => 'Auswahl aufheben',
        't_regtext'            => 'Register',
        'back'                 => 'back',
        'readmore'             => 'Read More',
        'phone'                => 'Phone Number',
        'showtabledetails'     => 'show Table Details',
        'navigation'           => 'Navigation',
        'register'             => 'Register',
        'mailsubject'          => 'Register',
        'execsql'              => 'Exec Sql',
        'news'                 => 'News',
        'headline'             => 'Headline',
        'edit entry'           => 'Edit Entry',
        'caption'              => 'Caption',
        'regmessage'           => 'You receive this email from Lindnerei.de',
        'kontakt'              => 'kontakt',
        'lang'                 => 'en',
        'newfile'              => 'Files',
        'folderfirst'          => 'folderFirst',
        'sql'                  => 'SQL',
        'saveentry'            => 'saveentry',
        'makierte'             => 'makierte',
        'edittree'             => 'Edit',
        'username'             => 'User',
        'edit translation'     => 'edit translation',
        'deletetreeviewentry'  => 'Delete',
        'showtable'            => 'ShowTable',
        'explorer'             => 'Explorer',
        'news_pro_page'        => 'news_pro_page',
        'optimizetable'        => 'Optimize Table',
        'welcome'              => 'Welcome',
        'schreib mir was'      => 'schreib mir was',
        'packed'               => 'Packed',
        'edit'                 => 'Bearbeiten',
        'newpost'              => 'New Message',
        'body'                 => 'Body',
        'summary'              => 'Summary',
        'checkformsddfsds'     => 'true',
        'edittreeviewentry'    => 'Edit',
        'editfile'             => 'editfile',
        'newfileadded'         => 'New File created',
        'referer'              => 'referer',
        'choosefile'           => 'Choose Attachment',
        'edit links'           => 'Edit links',
        'deleteentry'          => 'Delete Entry',
        'env'                  => 'Env',
        'key_name'             => 'Key_name',
        'database'             => 'Database',
        'reg'                  => 'Register ',
        'inserttext'           => 'Insert Text',
        'firstname'            => 'firstname',
        'search'               => 'Search',
        'done'                 => 'done',
        'street'               => 'Street',
        'insertpass'           => 'Insert Password',
        'edit table'           => 'Edit Table',
        'about'                => 'about',
        'floodtext'            => 'To many Posts',
        'answers'              => 'Answers',
        'sites'                => 'Sites',
        'show'                 => 'Show',
        'nomail'               => 'No Email Adress given.',
        'insertname'           => 'Insert Your Name',
        'fileexists'           => 'File already Exists',
        'newtreeviewentry'     => 'New Entry',
        'downentry'            => 'Sort',
        'buildfeeds'           => 'Rss Feeds',
        'edittreeview'         => 'Edit',
        'newtable'             => 'New Table',
        'userexits'            => 'This name is olready in use.<br/>',
        'wrongpass'            => 'Wrong Password',
        'daten'                => 'Daten',
        'alle markieren'       => 'Alle markieren',
        'impressum'            => 'Impressum',
        'sub_part'             => 'Sub_part',
        'gbook_body'           => 'Write your entry',
        'mysqldump'            => 'Mysql dump',
        'realy'                => 'Realy',
        'help'                 => 'Hilfe',
        'editmessage'          => 'Edit',
        'postcode'             => 'Postcode',
        'gbook'                => 'Gbook',
        'dumptable'            => 'dumptable',
        'databases'            => 'Databases',
        'blog'                 => 'Weblog',
        'm_hrSettings'             => 'Settings',
        'seq_in_index'         => 'Seq_in_index',
        'reply'                => 'Antworten',
        'comment'              => 'Comment',
        'action'               => 'Action',
        'newmessage'           => 'New Topic',
        'showwindow'           => 'Show Windows'
    },
    'de' => {
        'openfile'                => 'Explorer',
        'save'                    => 'Speichern',
        'rename'                  => 'umbenennen',
        'email'                   => 'Email Adresse',
        'optionale email adresse' => 'optionale email adresse',
        'wrongusername' =>
            'Sie haben keinen oder einen ung&#252;ltigen usernamen eingegeben, bitte eingabe wiederhohlen.<br/>',
        'password'         => 'Passwort',
        'admincenter'      => 'Admin Center',
        'logout'           => 'Abmelden',
        'category'         => 'Kategorie',
        'dein name'        => 'dein name',
        'newmenu'          => 'Neues Menu erstellen',
        'name'             => 'Name',
        'details'          => 'Details',
        'dumpdatabase'     => 'dumpdatabase',
        'nachricht senden' => 'nachricht senden',
        'trash'            => 'M&#252;lleimer',
        'translate'        => '&#220;bersetzen',
        'delete'           => 'L&#246;schen',
        'chars'            => 'Zeichen &#252;brig:',
        'editvmenu'        => 'Vertikales Menu',
        'sitemap'          => '&#252;bersicht',
        'links_pro_page'   => 'Eintr&auml;ge/Seite',
        'non_unique'       => 'Nicht Unique',
        'mailsendet' =>
            '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
        'deletefile'           => 'Explorer',
        'cardinality'          => 'Kardinalit&auml;t',
        'speichern'            => 'Speichern',
        'pass'                 => 'Passwort',
        'edithmenu'            => 'Horizontales Menu',
        'sort'                 => 'Sortieren',
        'edittableprops'       => 'bearbeiten',
        'index_type'           => 'Type',
        'profile'              => 'Einstelliúngen',
        'next'                 => 'weiter',
        'feeds'                => 'Rss',
        'importoperabookmarks' => 'Opera Lezeichen importieren',
        'upentry'              => 'TreeView',
        'newentry'             => 'Neuer Eintrag',
        'editaction'           => 'Aktion bearbeiten',
        'nachricht'            => 'nachricht',
        'chmodfile'            => 'Explorer',
        'makedir'              => 'Explorer',
        'lostpass'             => 'Passwort vergessen',
        'savefile'             => 'Speichern',
        'export'               => 'Exportieren',
        'haveacount'           => 'Sie haben bereits einen Acount',
        'savetreeviewentry'    => 'TreeView',
        'links'                => 'Lesezeichen',
        'addtreeviewentry'     => 'Hinzuf&#252;gen',
        'admin'                => 'Administrator',
        'newdir'               => 'Explorer',
        'editentry'            => 'Eintrag bearbeiten',
        'getpass'              => 'Passwort vergessen',
        'null'                 => 'Null',
        'retry'                => 'Wiederholen',
        'exportoperabookmarks' => 'Opera Lesezeichen exportieren',
        'preview'              => 'Vorschau',
        'bookmarks'            => 'Lesezeichen',
        'repairtable'          => 'Reparieren',
        'newpass'              => 'Neues Passwort',
        'city'                 => 'Stadt',
        'column_name'          => 'Spalten Name',
        'showtables'           => 'Anzeigen',
        'analyzetable'         => 'Analysieren',
        'familyname'           => 'Nachname',
        'auswahl aufheben'     => 'Auswahl aufheben',
        'back'                 => 'zur&uuml;ck',
        't_regtext'            => 'Registrieren',
        'readmore'             => 'ganzen Atikel lesen',
        'phone'                => 'Telefonnummer',
        'showtabledetails'     => 'Details',
        'register'             => 'Registrieren',
        'navigation'           => 'Navigation',
        'mailsubject'          => 'Registrieren',
        'news'                 => 'Neues',
        'execsql'              => 'Sql ausf&uuml;hren',
        'headline'             => '&#220;berschrift',
        'edit entry'           => 'Eintrag Bearbeiten',
        'caption'              => '&#220;berschrift',
        'regmessage' =>
            'Sie ehalten diese Email weil versucht wurde sich auf damit bei uns zu registrieren \\nWenn Sie diese Mail nicht angefordert haben bitte ich um entschuldigung.\\nAnsonsten lautet ihr \\n',
        'kontakt'             => 'kontakt',
        'newfile'             => 'Explorer',
        'folderfirst'         => 'Verzeichnisse zuerst',
        'sql'                 => 'SQL',
        'saveentry'           => 'saveentry',
        'makierte'            => 'makierte',
        'edittree'            => 'Bearbeiten',
        'username'            => 'Benutzer',
        'deletetreeviewentry' => 'L&#246;sche',
        'showtable'           => 'Tabelle Anzeigen',
        'explorer'            => 'Explorer',
        'news_pro_page'       => 'Nachrichten/Seite',
        'optimizetable'       => 'Optimieren',
        'welcome'             => 'Willkommen',
        'schreib mir was'     => 'schreib mir was',
        'packed'              => 'gepackt',
        'edit'                => 'Bearbeiten',
        'newpost'             => 'Neue Nachricht',
        'body'                => 'Text',
        'summary'             => 'Zusammenfassung',
        'edittreeviewentry'   => 'Bearbeiten',
        'editfile'            => 'Datei bearbeiten',
        'newfileadded'        => 'Neue Datei wurde erstellt',
        'referer'             => 'Referer',
        'choosefile'          => 'File ausw&#228;hlen',
        'edit links'          => 'Lesezeichen bearbeiten',
        'deleteentry'         => 'Eintrag l&#246;schen',
        'env'                 => 'Variablen',
        'key_name'            => 'Schl&uuml;ssel',
        'database'            => 'Datenbank',
        'reg'                 => 'Registrieren',
        'inserttext'          => 'Text einf&#252;gen',
        'firstname'           => 'Vorname',
        'search'              => 'Suchen',
        'done'                => 'Gespeichert',
        'street'              => 'Strasse',
        'insertpass'          => 'Passwort eingeben',
        'edit table'          => 'Bearbeiten',
        'about'               => 'Über',
        'floodtext'           => 'Nicht so oft posten',
        'answers'             => 'Antworten',
        'sites'               => 'Seiten',
        'show'                => 'Anzeigen',
        'nomail'              => 'Sie haben keine email adresse angegeben.',
        'insertname'          => 'Namen eingeben',
        'fileexists'          => 'Datei existiert bereits',
        'newtreeviewentry'    => 'Neuer Eintrag',
        'downentry'           => 'TreeView',
        'buildfeeds'          => 'Rss',
        'edittreeview'        => 'Bearbeiten',
        'newtable'            => 'Neue Tabelle',
        'userexits' =>
            'Dieser Benutzer exestiert bereits bitte einen anderen Namen ausw&#228;hlen<br/>',
        'wrongpass'      => 'Falsches Passwort',
        'alle markieren' => 'Alle markieren',
        'daten'          => 'Daten',
        'gbook_body'     => 'Text einf&#252;gen',
        'sub_part'       => 'Sub Part',
        'impressum'      => 'Impressum',
        'mysqldump'      => 'Mysql dump',
        'realy'          => 'Wirklich',
        'help'           => 'Hilfe',
        'postcode'       => 'Postleitzahl',
        'editmessage'    => 'Bearbeiten',
        'gbook'          => 'G&#228;stebuch',
        'dumptable'      => 'Tabelle exportieren',
        'databases'      => 'Datenbanken',
        'blog'           => 'Weblog',
        'm_hrSettings'       => 'Einstellungen',
        'reply'          => 'Antworten',
        'seq_in_index'   => 'Seq',
        'comment'        => 'Kommentar',
        'action'         => 'Aktion',
        'showwindow'     => 'Fenster anzeigen',
        'newmessage'     => 'Neue Nachricht'
    }
};
$lang = $VAR1;

==> CGI-CMS-0.39.tar.gz: CGI-CMS-0.39/cgi-bin/config/translate.pl <==
$VAR1 = {
    'en' => {
        'files'                   => 'Files',
        'openfile'                => 'Files',
        'save'                    => 'Save',
        'rename'                  => 'rename',
        'email'                   => 'Email Adress',
        'optionale email adresse' => 'optionale email adresse',
        'wrongusername'           => 'Wrong Username',
        'password'                => 'Password',
        'admincenter'             => 'Admin Center',
        'logout'                  => 'Logout',
        'category'                => 'Category',
        'dein name'               => 'dein name',
        'newmenu'                 => 'Create new Menu',
        'name'                    => 'Name',
        'details'                 => 'Details',
        'dumpdatabase'            => 'dumpdatabase',
        'properties'              => 'Properties',
        'nachricht senden'        => 'nachricht senden',
        'trash'                   => 'Trash',
        'translate'               => 'Translate',
        'delete'                  => 'Delete',
        'chars'                   => 'Chars left:',
        'editvmenu'               => 'editvmenu',
        'links_pro_page'          => 'links_pro_page',
        'non_unique'              => 'Non_unique',
        'mailsendet' =>
            '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
        'deletefile'           => 'Files',
        'cardinality'          => 'Cardinality',
        'speichern'            => 'Speichern',
        'pass'                 => 'Password',
        'edithmenu'            => 'edithmenu',
        'edittableprops'       => 'editTableProps',
        'sort'                 => 'sort',
        'index_type'           => 'Index_type',
        'profile'              => 'Profile',
        'next'                 => 'next',
        'feeds'                => 'Rss Feeds',
        'importoperabookmarks' => 'ImportOperaBookmarks',
        'upentry'              => 'Sort',
        'newentry'             => 'New Entry',
        'editaction'           => 'editaction',
        'nachricht'            => 'nachricht',
        'chmodfile'            => 'Files',
        'makedir'              => 'Files',
        'lostpass'             => 'Lost passwort',
        'savefile'             => 'Save',
        'export'               => 'Export',
        'haveacount'           => 'You already have an Acount',
        'savetreeviewentry'    => 'Save',
        'links'                => 'Bookmarks',
        'addtreeviewentry'     => 'Add new entry',
        'admin'                => 'Admin',
        'newdir'               => 'Files',
        'editentry'            => 'Edit Entry',
        'getpass'              => 'Lost Password',
        'null'                 => 'Null',
        'retry'                => 'retry',
        'exportoperabookmarks' => 'exportoperabookmarks',
        'preview'              => 'Preview',
        'bookmarks'            => 'Bookmarks',
        'repairtable'          => 'Repair Table',
        'newpass'              => 'New Password',
        'city'                 => 'City',
        'column_name'          => 'Column_name',
        'showtables'           => 'Show Tables',
        'analyzetable'         => 'Analyze Table',
        'familyname'           => 'Family Name',
        'auswahl aufheben'     => 'Auswahl aufheben',
        't_regtext'            => 'Register',
        'back'                 => 'back',
        'readmore'             => 'Read More',
        'phone'                => 'Phone Number',
        'showtabledetails'     => 'show Table Details',
        'navigation'           => 'Navigation',
        'register'             => 'Register',
        'mailsubject'          => 'Register',
        'execsql'              => 'Exec Sql',
        'news'                 => 'News',
        'headline'             => 'Headline',
        'edit entry'           => 'Edit Entry',
        'caption'              => 'Caption',
        'regmessage'           => 'You receive this email from Lindnerei.de',
        'kontakt'              => 'kontakt',
        'lang'                 => 'en',
        'newfile'              => 'Files',
        'folderfirst'          => 'folderFirst',
        'sql'                  => 'SQL',
        'saveentry'            => 'saveentry',
        'makierte'             => 'makierte',
        'edittree'             => 'Edit',
        'username'             => 'User',
        'edit translation'     => 'edit translation',
        'deletetreeviewentry'  => 'Delete',
        'showtable'            => 'ShowTable',
        'explorer'             => 'Explorer',
        'news_pro_page'        => 'news_pro_page',
        'optimizetable'        => 'Optimize Table',
        'welcome'              => 'Welcome',
        'schreib mir was'      => 'schreib mir was',
        'packed'               => 'Packed',
        'edit'                 => 'Bearbeiten',
        'newpost'              => 'New Message',
        'body'                 => 'Body',
        'summary'              => 'Summary',
        'checkformsddfsds'     => 'true',
        'edittreeviewentry'    => 'Edit',
        'editfile'             => 'editfile',
        'newfileadded'         => 'New File created',
        'referer'              => 'referer',
        'choosefile'           => 'Choose Attachment',
        'edit links'           => 'Edit links',
        'deleteentry'          => 'Delete Entry',
        'env'                  => 'Env',
        'key_name'             => 'Key_name',
        'database'             => 'Database',
        'reg'                  => 'Register ',
        'inserttext'           => 'Insert Text',
        'firstname'            => 'firstname',
        'search'               => 'Search',
        'done'                 => 'done',
        'street'               => 'Street',
        'insertpass'           => 'Insert Password',
        'edit table'           => 'Edit Table',
        'about'                => 'about',
        'floodtext'            => 'To many Posts',
        'answers'              => 'Answers',
        'sites'                => 'Sites',
        'show'                 => 'Show',
        'nomail'               => 'No Email Adress given.',
        'insertname'           => 'Insert Your Name',
        'fileexists'           => 'File already Exists',
        'newtreeviewentry'     => 'New Entry',
        'downentry'            => 'Sort',
        'buildfeeds'           => 'Rss Feeds',
        'edittreeview'         => 'Edit',
        'newtable'             => 'New Table',
        'userexits'            => 'This name is olready in use.<br/>',
        'wrongpass'            => 'Wrong Password',
        'daten'                => 'Daten',
        'alle markieren'       => 'Alle markieren',
        'impressum'            => 'Impressum',
        'sub_part'             => 'Sub_part',
        'gbook_body'           => 'Write your entry',
        'mysqldump'            => 'Mysql dump',
        'realy'                => 'Realy',
        'help'                 => 'Hilfe',
        'editmessage'          => 'Edit',
        'postcode'             => 'Postcode',
        'gbook'                => 'Gbook',
        'dumptable'            => 'dumptable',
        'databases'            => 'Databases',
        'blog'                 => 'Weblog',
        'm_hrSettings'             => 'Settings',
        'seq_in_index'         => 'Seq_in_index',
        'reply'                => 'Antworten',
        'comment'              => 'Comment',
        'action'               => 'Action',
        'newmessage'           => 'New Topic',
        'showwindow'           => 'Show Windows'
    },
    'de' => {
        'openfile'                => 'Explorer',
        'save'                    => 'Speichern',
        'rename'                  => 'umbenennen',
        'email'                   => 'Email Adresse',
        'optionale email adresse' => 'optionale email adresse',
        'wrongusername' =>
            'Sie haben keinen oder einen ung&#252;ltigen usernamen eingegeben, bitte eingabe wiederhohlen.<br/>',
        'password'         => 'Passwort',
        'admincenter'      => 'Admin Center',
        'logout'           => 'Abmelden',
        'category'         => 'Kategorie',
        'dein name'        => 'dein name',
        'newmenu'          => 'Neues Menu erstellen',
        'name'             => 'Name',
        'details'          => 'Details',
        'dumpdatabase'     => 'dumpdatabase',
        'nachricht senden' => 'nachricht senden',
        'trash'            => 'M&#252;lleimer',
        'translate'        => '&#220;bersetzen',
        'delete'           => 'L&#246;schen',
        'chars'            => 'Zeichen &#252;brig:',
        'editvmenu'        => 'Vertikales Menu',
        'sitemap'          => '&#252;bersicht',
        'links_pro_page'   => 'Eintr&auml;ge/Seite',
        'non_unique'       => 'Nicht Unique',
        'mailsendet' =>
            '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
        'deletefile'           => 'Explorer',
        'cardinality'          => 'Kardinalit&auml;t',
        'speichern'            => 'Speichern',
        'pass'                 => 'Passwort',
        'edithmenu'            => 'Horizontales Menu',
        'sort'                 => 'Sortieren',
        'edittableprops'       => 'bearbeiten',
        'index_type'           => 'Type',
        'profile'              => 'Einstellingen',
        'next'                 => 'weiter',
        'feeds'                => 'Rss',
        'importoperabookmarks' => 'Opera Lezeichen importieren',
        'upentry'              => 'TreeView',
        'newentry'             => 'Neuer Eintrag',
        'editaction'           => 'Aktion bearbeiten',
        'nachricht'            => 'nachricht',
        'chmodfile'            => 'Explorer',
        'makedir'              => 'Explorer',
        'lostpass'             => 'Passwort vergessen',
        'savefile'             => 'Speichern',
        'export'               => 'Exportieren',
        'haveacount'           => 'Sie haben bereits einen Acount',
        'savetreeviewentry'    => 'TreeView',
        'links'                => 'Lesezeichen',
        'addtreeviewentry'     => 'Hinzuf&#252;gen',
        'admin'                => 'Administrator',
        'newdir'               => 'Explorer',
        'editentry'            => 'Eintrag bearbeiten',
        'getpass'              => 'Passwort vergessen',
        'null'                 => 'Null',
        'retry'                => 'Wiederholen',
        'exportoperabookmarks' => 'Opera Lesezeichen exportieren',
        'preview'              => 'Vorschau',
        'bookmarks'            => 'Lesezeichen',
        'repairtable'          => 'Reparieren',
        'newpass'              => 'Neues Passwort',
        'city'                 => 'Stadt',
        'column_name'          => 'Spalten Name',
        'showtables'           => 'Anzeigen',
        'analyzetable'         => 'Analysieren',
        'familyname'           => 'Nachname',
        'auswahl aufheben'     => 'Auswahl aufheben',
        'back'                 => 'zur&uuml;ck',
        't_regtext'            => 'Registrieren',
        'readmore'             => 'ganzen Atikel lesen',
        'phone'                => 'Telefonnummer',
        'showtabledetails'     => 'Details',
        'register'             => 'Registrieren',
        'navigation'           => 'Navigation',
        'mailsubject'          => 'Registrieren',
        'news'                 => 'Neues',
        'execsql'              => 'Sql ausf&uuml;hren',
        'headline'             => '&#220;berschrift',
        'edit entry'           => 'Eintrag Bearbeiten',
        'caption'              => '&#220;berschrift',
        'regmessage' =>
            'Sie ehalten diese Email weil versucht wurde sich auf damit bei uns zu registrieren \\nWenn Sie diese Mail nicht angefordert haben bitte ich um entschuldigung.\\nAnsonsten lautet ihr \\n',
        'kontakt'             => 'kontakt',
        'newfile'             => 'Explorer',
        'folderfirst'         => 'Verzeichnisse zuerst',
        'sql'                 => 'SQL',
        'saveentry'           => 'saveentry',
        'makierte'            => 'makierte',
        'edittree'            => 'Bearbeiten',
        'username'            => 'Benutzer',
        'deletetreeviewentry' => 'L&#246;sche',
        'showtable'           => 'Tabelle Anzeigen',
        'explorer'            => 'Explorer',
        'news_pro_page'       => 'Nachrichten/Seite',
        'optimizetable'       => 'Optimieren',
        'welcome'             => 'Willkommen',
        'schreib mir was'     => 'schreib mir was',
        'packed'              => 'gepackt',
        'edit'                => 'Bearbeiten',
        'newpost'             => 'Neue Nachricht',
        'body'                => 'Text',
        'summary'             => 'Zusammenfassung',
        'edittreeviewentry'   => 'Bearbeiten',
        'editfile'            => 'Datei bearbeiten',
        'newfileadded'        => 'Neue Datei wurde erstellt',
        'referer'             => 'Referer',
        'choosefile'          => 'File ausw&#228;hlen',
        'edit links'          => 'Lesezeichen bearbeiten',
        'deleteentry'         => 'Eintrag l&#246;schen',
        'env'                 => 'Variablen',
        'key_name'            => 'Schl&uuml;ssel',
        'database'            => 'Datenbank',
        'reg'                 => 'Registrieren',
        'inserttext'          => 'Text einf&#252;gen',
        'firstname'           => 'Vorname',
        'search'              => 'Suchen',
        'done'                => 'Gespeichert',
        'street'              => 'Strasse',
        'insertpass'          => 'Passwort eingeben',
        'edit table'          => 'Bearbeiten',
        'about'               => 'ber',
        'floodtext'           => 'Nicht so oft posten',
        'answers'             => 'Antworten',
        'sites'               => 'Seiten',
        'show'                => 'Anzeigen',
        'nomail'              => 'Sie haben keine email adresse angegeben.',
        'insertname'          => 'Namen eingeben',
        'fileexists'          => 'Datei existiert bereits',
        'newtreeviewentry'    => 'Neuer Eintrag',
        'downentry'           => 'TreeView',
        'buildfeeds'          => 'Rss',
        'edittreeview'        => 'Bearbeiten',
        'newtable'            => 'Neue Tabelle',
        'userexits' =>
            'Dieser Benutzer exestiert bereits bitte einen anderen Namen ausw&#228;hlen<br/>',
        'wrongpass'      => 'Falsches Passwort',
        'alle markieren' => 'Alle markieren',
        'daten'          => 'Daten',
        'gbook_body'     => 'Text einf&#252;gen',
        'sub_part'       => 'Sub Part',
        'impressum'      => 'Impressum',
        'mysqldump'      => 'Mysql dump',
        'realy'          => 'Wirklich',
        'help'           => 'Hilfe',
        'postcode'       => 'Postleitzahl',
        'editmessage'    => 'Bearbeiten',
        'gbook'          => 'G&#228;stebuch',
        'dumptable'      => 'Tabelle exportieren',
        'databases'      => 'Datenbanken',
        'blog'           => 'Weblog',
        'm_hrSettings'       => 'Einstellungen',
        'reply'          => 'Antworten',
        'seq_in_index'   => 'Seq',
        'comment'        => 'Kommentar',
        'action'         => 'Aktion',
        'showwindow'     => 'Fenster anzeigen',
        'newmessage'     => 'Neue Nachricht'
    }
};
$lang = $VAR1;
